/*****************************************************************************
* File Name: accelerometer.h
* Version 1.0
*
* Description:
*  This file contains the function prototypes and constants used in
*  accelerometer.c
*
******************************************************************************
* Copyright (2015), Cypress Semiconductor Corporation.
******************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*****************************************************************************/
#if !defined(ACCELEROMETER_H) 
#define ACCELEROMETER_H 

#include "cytypes.h"

/*****************************************************************************
* MACRO Definition
*****************************************************************************/
#define ACCELEROMETER_ADDR      0x53
#define ACCELEROMETER_ALT_ADDR  0x1d
    
#define COMM_FAIL				0x01
#define COMM_PASS				0x00
    
#define ACC_WRITE				0x3A
#define ACC_READ				0x3B
    

#define ACC_ALT_WRITE			0x6A
#define ACC_ALT_READ	        0x6B

#define ACC_ACK					0x00
#define ACC_NACK				0x01

#define ACC_FAIL				0x00
#define ACC_PASS				0x01
    

#define DEVID                   0x00
#define THRESH_TAP              0x1D
#define OSFX                    0x1E
#define OSFY                    0x1F
#define OFSZ                    0x20
#define DUR                     0x21
#define Latent                  0x22
#define WINDOW                  0x23
#define THRESH_ACT              0x24
#define THRESH_INACT            0x25
#define TIME_INACT              0x26
#define ACT_INACT_CTL           0x27
#define THRESH_FF               0x28
#define TIME_FF                 0x29
#define TAP_AXES                0x2A
#define ACT_TAP_STATUS          0x2B
#define BW_RATE                 0x2C
#define POWER_CTL               0x2D
#define INT_ENABLE              0x2E
#define INT_MAP                 0x2F
#define INT_SOURCE              0x30
#define DATA_FORMAT             0x31
#define DATAX0                  0x32
#define DATAX1                  0x33
#define DATAY0                  0x34
#define DATAY1                  0x35
#define DATAZ0                  0x36
#define DATAZ1                  0x37
#define FIFO_CTL                0x38
#define FIFO_STATUS             0x39

#define ACC_NO_MOVEMENT			0x00

#define ZERO					0x00	
	
#define TRUE					0x01
#define FALSE					0x00
    
/*****************************************************************************
* Changing Register Values MASKS
*****************************************************************************/

/* ACTIVITY, INACTIVITY CONTROL */
#define ACT_AC_OR               0x80
#define ACT_X_ENABLE_OR         0x40
#define ACT_Y_ENABLE_OR         0x20
#define ACT_Z_ENABLE_OR         0x10
#define INACT_AC_OR             0x08
#define INACT_X_ENABLE_OR       0x04
#define INACT_Y_ENABLE_OR       0x02
#define INACT_Z_ENABLE_OR       0x01
    
#define ACT_DC_AND              0x7F
#define ACT_X_DISABLE_AND       0xBF
#define ACT_Y_DISABLE_AND       0xDF
#define ACT_Z_DISABLE_AND       0xEF
#define INACT_DC_AND            0xF7
#define INACT_X_DISABLE_AND     0xFB
#define INACT_Y_DISABLE_AND     0xFD
#define INACT_Z_DISABLE_AND     0xFE
    
    
/* TAP AND TAP-AXES CONTROL */
#define SUPRESS_DT_OR           0x08
#define TAP_X_ENABLE_OR         0x04
#define TAP_Y_ENABLE_OR         0x02
#define TAP_Z_ENABLE_OR         0x01
    
#define DT_ENABLE_AND           0xF7
#define TAP_X_DISABLE_AND       0xFB
#define TAP_Y_DISABLE_AND       0xFD
#define TAP_Z_DISABLE_AND       0xFE
    
    
/* SLEEP AND BW-RATE CONTROL */
#define LOW_POWER_OR            0x10
#define RATE_BIT3_OR            0x08
#define RATE_BIT2_OR            0x04
#define RATE_BIT1_OR            0x02
#define RATE_BIT0_OR            0x01
    
#define NORMAL_AND              0xEF
#define RATE_BIT3_AND           0xF7
#define RATE_BIT2_AND           0xFB
#define RATE_BIT1_AND           0xFD
#define RATE_BIT0_AND           0xFE
    
    
/* POWER CONTROL */
#define LINK_OR                 0x20
#define AUTO_SLEEP_ON_OR        0x10
#define OUT_OF_STANDBY_OR       0x08
#define GOTO_SLEEP_OR           0x04
    
#define LINK_AND                0xDF
#define AUTO_SLEEP_OFF_AND      0xEF
#define STANDBYMODE_AND         0xF7
#define WAKEUP_AND              0xFB
    
    
/* INTERRUPT ENABLE */
#define DATA_READY_ENABLE_OR    0x80
#define SINGLE_TAP_ENABLE_OR    0x40
#define DOUBLE_TAP_ENABLE_OR    0x20
#define ACTIVITY_ENABLE_OR      0x10
#define INACTIVITY_ENABLE_OR    0x08
#define FREE_FALL_ENABLE_OR     0x04
#define WATERMARK_ENABLE_OR     0x02
#define OVERRUN_ENABLE_OR       0x01
    
#define DATA_READY_DISABLE_AND  0x7F
#define SINGLE_TAP_DISABLE_AND  0xBF
#define DOUBLE_TAP_DISABLE_AND  0xDF
#define ACTIVITY_DISABLE_AND    0xEF
#define INACTIVITY_DISABLE_AND  0xF7
#define FREE_FALL_DISABLE_AND   0xFB
#define WATERMARK_DISABLE_AND   0xFD
#define OVERRUN_DISABLE_AND     0xFE
    
    
/* INTERRUPT MAPPING */
#define DATA_READY_INT2_OR      0x80
#define SINGLE_TAP_INT2_OR      0x40
#define DOUBLE_TAP_INT2_OR      0x20
#define ACTIVITY_INT2_OR        0x10
#define INACTIVITY_INT2_OR      0x08
#define FREE_FALL_INT2_OR       0x04
#define WATERMARK_INT2_OR       0x02
#define OVERRUN_INT2_OR         0x01
    
#define DATA_READY_INT1_AND     0x7F
#define SINGLE_TAP_INT1_AND     0xBF
#define DOUBLE_TAP_INT1_AND     0xDF
#define ACTIVITY_INT1_AND       0xEF
#define INACTIVITY_INT1_AND     0xF7
#define FREE_FALL_INT1_AND      0xFB
#define WATERMARK_INT1_AND      0xFD
#define OVERRUN_INT1_AND        0xFE   
    
    
    
/* DATA FORMAT */
#define SELF_TEST_APPLY_OR      0x80
#define THREE_WIRE_SPI_OR       0x40
#define INT_ACTIVE_HIGH_OR      0x20
#define FULL_RES_OR             0x08
#define MSB_JUSTIFIED_OR        0x04
#define RANGE_BIT1_OR           0x02
#define RANGE_BIT0_OR           0x01
    
#define NO_SELF_TEST_AND        0x7F
#define FOUR_WIRE_SPI_AND       0xBF
#define INT_ACTIVE_LOW_AND      0xDF
#define TEN_BIT_RES_AND         0xF7
#define WITH_SIGN_AND           0xFB
#define RANGE_BIT1_AND          0xFD
#define RANGE_BIT0_AND          0xFE
    
    
    
/* FIFO CONTROL */
#define FIFO_MODE_BIT1_OR       0x80
#define FIFO_MODE_BIT0_OR       0x40
#define TRIGGER_INT2_OR         0x20
#define SAMPLES_BIT4_OR         0x10
#define SAMPLES_BIT3_OR         0x08
#define SAMPLES_BIT2_OR         0x04
#define SAMPLES_BIT1_OR         0x02
#define SAMPLES_BIT0_OR         0x01
    
#define FIFO_MODE_BIT1_AND      0x7F
#define FIFO_MODE_BIT0_AND      0xBF
#define TRIGGER_INT1_AND        0xDF
#define SAMPLES_BIT4_AND        0xEF
#define SAMPLES_BIT3_AND        0xF7
#define SAMPLES_BIT2_AND        0xFB
#define SAMPLES_BIT1_AND        0xFD
#define SAMPLES_BIT0_AND        0xFE 
    
    
/*****************************************************************************
* Data Type Definition
*****************************************************************************/


/*****************************************************************************
* Enumerated Data Definition
*****************************************************************************/


/*****************************************************************************
* Data Structure Definition
*****************************************************************************/


/*****************************************************************************
* Global Variable Declaration
*****************************************************************************/
extern uint8 acclerometer_configured;

/*****************************************************************************
* Function Prototypes
*****************************************************************************/
void InitializeAccelerometer(void);
void SleepAccelerometer(void);
void WakeAccelerometer(void);
void ReadAccelerometer(uint16 *xData, uint16 *yData, uint16 *zData);
uint8 Accelerometer_RegRead(uint8 reg, uint8 *value);

/*****************************************************************************
* External Function Prototypes
*****************************************************************************/
	
	
#endif /* ACCELEROMETER_H */

/* [] END OF FILE */

